clear all
version 12
set more off

do "/home/home2/qureshi_rs1/teacher_sorting/directory_do"

cd "$data"
use finaldata.dta, clear

display c(current_time)

/*
Creates Table 1: Summary Statistics
*/

*Student Characteristics
collapse mastid White Black Hispanic Other eds preread preread_ltm, by(my)
save "$data/student_collapsed.dta", replace

*Add Female back into the data
use "$data/panel2_rr_1a.dta", clear
keep mastid year Female
egen my = group(mastid year)
duplicates drop

merge 1:1 my using "$data/student_collapsed.dta"
drop if _merge == 1
drop _merge
duplicates drop

lab var Female "Female"
lab var White "White"
lab var Black "Black"
lab var Hispanic "Hispanic"
lab var Other "Other race"
lab var eds "Poor"
lab var preread "Lagged reading score"
lab var preread_ltm "Low achieving"

**Summarize Student characteristics
estpost tabstat Female White Black Hispanic Other eds preread preread_ltm, statistics(mean sd) columns(statistics)
est store t1a

esttab t1a using "$tables/Final_RR_Tables.txt", cells("mean sd") label replace title("Table 1: Summary Statistics")



*Teacher Characteristics
cd "$data"
use finaldata.dta, clear

egen py = group(ptch year)

collapse expgt3i more_than_BA nbpts va, by(py)
save "$data/teacher_collapsed.dta", replace

*Add teacher race, continuous experience back into the data
use "$data/panel2_rr_1a.dta", clear
keep ptch year exp tch_rwhite tch_rblack tch_rhisp tch_roth
egen py = group(ptch year)
duplicates drop

merge 1:1 py using "$data/teacher_collapsed.dta"
drop if _merge == 1
drop _merge
duplicates drop

lab var exp "Years of experience"
lab var expgt3i "Experience >= 3 years"
lab var more_than_BA "Advanced degree"
lab var nbpts "National Board certified"
lab var va "Value-added"
lab var tch_rwhite "White"
lab var tch_rblack "Black"
lab var tch_rhisp "Hispanic"
lab var tch_roth "Other race"

**Summarize Teacher characteristics
estpost tabstat exp expgt3i more_than_BA nbpts va tch_rwhite tch_rblack tch_rhisp tch_roth, statistics(mean sd) columns(statistics)
est store t1b

esttab t1b using "$tables/Final_RR_Tables.txt", cells("mean sd") label append title("Table 1: Summary Statistics")



*School Characteristics
cd "$data"
use finaldata.dta, clear

forvalues n = 2/5 {
	gen ntch`n' = (n_tch == `n')
}

gen ntch_big = (n_tch > 5 & n_tch != .)

collapse n_tch ntch2 ntch3 ntch4 ntch5 ntch_big, by(schgryr)

lab var n_tch "Number of Teachers"
lab var ntch2 "Two teachers in grade"
lab var ntch3 "Three teachers in grade"
lab var ntch4 "Four teachers in grade"
lab var ntch5 "Five teachers in grade"
lab var ntch_big "More than five teachers in grade"

**Summarize School characteristics
estpost tabstat ntch2 ntch3 ntch4 ntch5 ntch_big, statistics(mean sd) columns(statistics)
est store t1c

esttab t1c using "$tables/Final_RR_Tables.txt", cells("mean sd") label append title("Table 1: Summary Statistics") addnote("Note: The top panel represents summary statistics of student characteristics for the 780,320 student-year observations in our analysis sample. The second panel includes characteristics of potential teachers measured at the teacher-year level and the bottom panel shows the distribution of potential teachers across 10,424 school-grade-year cells.")



