clear all
version 12
set more off
cap log close

do "/home/home2/qureshi_rs1/teacher_sorting/directory_do"

/*
This do-file runs the simulations to determine if students are assigned to their older siblings' teachers at a rate greater than chance would predict.
*/

use "$data/finaldata.dta"

gen preread_gtm = 1 - preread_ltm

**Actual Rate**
display "All Students, All Grades"
summ real_match
local match_tot = r(mean)

forval tch = 2/5 {
	display " "
	display "`tch' teachers in SGY"
	summ real_match if n_tch == `tch'
	local match_tch`tch' = r(mean)
}

foreach race in White Black Hispanic Other {
	display " "
	display "Student's race is `race'"
	summ real_match if `race' == 1
	local match_`race' = r(mean)
}

foreach var in eds preread_gtm expgt3i more_than_BA nbpts va_gtm {
	display " "
	display "`var'==1"
	summ real_match if `var' == 1
	local match_`var'1 = r(mean)
	
	display " "
	display "`var'==0"
	summ real_match if `var' == 0
	local match_`var'0 = r(mean)
}

**** Create the simulation program *******************************************************************
cap program drop oldersib
program define oldersib,rclass

cap drop random_temp random match any_match_sim

gen random_temp = runiform() if kid_obs==1
egen random 	= max(random_temp),by(lea_r schlcode_fl grade year mastid)

**This randomly sorts the datat within a schl_grd_yr
sort lea_r schlcode_fl grade year random mastid
/*
If the random order of the student is in the range between lagged_cumulative_fraction and cumulative_fraction 
the student is assigned to this teacher.  This should keep the fraction assigned to each teacher accurate.
*/
gen match=.
replace match=0 if ostch==1
by lea_r schlcode_fl grade year: replace match=1 if _n/_N <= cumul_propst & _n/_N >lag_cumul_propst & ostch==1

***To run the simulation, the variable capturing the older sibling's teacher must be renamed ostch.***

egen any_match_sim=max(match) if ostch==1, by(lea_r schlcode_fl grade year mastid)


summ any_match_sim
return scalar match_rate=r(mean)

forval tch = 2/5 {
	summ any_match_sim if n_tch == `tch'
	return scalar match_rate_tch`tch'=r(mean)
}

foreach race in White Black Hispanic Other {
	summ any_match_sim if `race' == 1
	return scalar match_rate_`race'=r(mean)
}

foreach var in eds preread_gtm expgt3i more_than_BA nbpts va_gtm {
	summ any_match_sim if `var' == 1
	return scalar match_rate_`var'1=r(mean)
	
	summ any_match_sim if `var' == 0
	return scalar match_rate_`var'0=r(mean)
}

end
******************************************************************************************************

/******************************************************************************************************
Run unconditional simulations
******************************************************************************************************/


***Run simulation matching to any os teacher (either 4th or 5th grade) when ys in either grade
rename any_ostchp ostch
*test*
*oldersib

display c(current_time)
set seed 1495823
simulate frac_old_sib=r(match_rate) frac_os_tch2=r(match_rate_tch2) frac_os_tch3=r(match_rate_tch3) frac_os_tch4=r(match_rate_tch4) frac_os_tch5=r(match_rate_tch5) frac_os_White=r(match_rate_White) frac_os_Black=r(match_rate_Black) frac_os_Hispanic=r(match_rate_Hispanic) frac_os_Other=r(match_rate_Other) frac_os_eds1=r(match_rate_eds1) frac_os_eds0=r(match_rate_eds0) frac_os_preread_gtm1=r(match_rate_preread_gtm1) frac_os_preread_gtm0=r(match_rate_preread_gtm0) frac_os_expgt3i1=r(match_rate_expgt3i1) frac_os_expgt3i0=r(match_rate_expgt3i0) frac_os_more_than_BA1=r(match_rate_more_than_BA1) frac_os_more_than_BA0=r(match_rate_more_than_BA0) frac_os_nbpts1=r(match_rate_nbpts1) frac_os_nbpts0=r(match_rate_nbpts0) frac_os_va_gtm1=r(match_rate_va_gtm1) frac_os_va_gtm0=r(match_rate_va_gtm0), reps($max_iter) saving("$data/simresults.dta", replace) :oldersib
display c(current_time)


display " "
display "All Students"
summ frac_old_sib
count if frac_old_sib >= `match_tot'

forval tch = 2/5 {
	display " "
	display "`tch' Teacher in SGY"
	summ frac_os_tch`tch'
	count if frac_os_tch`tch' >= `match_tch`tch''
}

foreach race in White Black Hispanic Other {
	display " "
	display "`race' Students"
	summ frac_os_`race'
	count if frac_os_`race' >= `match_`race''
}

foreach var in eds preread_gtm expgt3i more_than_BA nbpts va_gtm {
	display " "
	display "`var'==1"
	summ frac_os_`var'1
	count if frac_os_`var'1 >= `match_`var'1'

	display " "
	display "`var'==0"
	summ frac_os_`var'0
	count if frac_os_`var'0 >= `match_`var'0'
}

/* Formatting Details:
Note: Results must be copied from the log file to an Excel file to create this table.
*/

do "$do_files/Jaselyn/tchsrt/cr_rr_tables/02b_SimFigs.do"



