clear all
version 12
set more off
cap log close

do "/home/home2/qureshi_rs1/teacher_sorting/directory_do"

/*
This do-file uses the simulated match rates to create kernel density plots of the distribution of results.
*/

***Actual Class Sizes
use "$data/finaldata.dta"

gen preread_gtm = 1- preread_ltm


quietly summ real_match
local match_tot = r(mean)
local match_tot = round(`match_tot',0.001)

forval tch = 2/5 {
	quietly summ real_match if n_tch == `tch'
	local match_tch`tch' = r(mean)
	local match_tch`tch' = round(`match_tch`tch'',0.001)
}

foreach race in White Black Hispanic Other {
	quietly summ real_match if `race' == 1
	local match_`race' = r(mean)
	local match_`race' = round(`match_`race'',0.001)
}

foreach var in eds preread_gtm expgt3i more_than_BA nbpts va_gtm {
	quietly summ real_match if `var' == 1
	local match_`var'1 = r(mean)
	local match_`var'1 = round(`match_`var'1',0.001)

	quietly summ real_match if `var' == 0
	local match_`var'0 = r(mean)
	local match_`var'0 = round(`match_`var'0',0.001)
}


**Create Figures

use "$data/simresults.dta", clear

**All Students**
quietly summ frac_old_sib
local varmin = r(min)
local varmin = round(`varmin',0.001)
local varmax = r(max)
local varmax = round(`varmax',0.001)
local scalemin = `varmin' - 0.005
local scalemax = cond(`varmax' > `match_tot', `varmax' + 0.005, `match_tot' + 0.005)
local labmin = `scalemin' + 0.003
local labmax = `scalemax' - 0.003

kdensity frac_old_sib, kernel(gaus) legend(off) ///
	title("All Students") ///
	xtitle("Share Assigned to Older Sibling's Teacher", size(medsmall)) ytitle("Density", size(medsmall)) ylabel(,labsize(small)) ///
	xline(`match_tot') xscale(range(`scalemin' `scalemax')) xlabel(`labmin' (0.01) `labmax', labsize(small))
graph export "$figures/Actual/01_AllStudents.pdf", replace


**Number of Teachers**
forval tch = 2/5 {
quietly summ frac_os_tch`tch'
local varmin = r(min)
local varmin = round(`varmin',0.001)
local varmax = r(max)
local varmax = round(`varmax',0.001)
local scalemin = `varmin' - 0.005
local scalemax = cond(`varmax' > `match_tch`tch'', `varmax' + 0.005, `match_tch`tch'' + 0.005)
local labmin = `scalemin' + 0.003
local labmax = `scalemax' - 0.003

kdensity frac_os_tch`tch', kernel(gaus) legend(off) ///
	title("Number of Teachers in Grade==`tch'") ///
	xtitle("Share Assigned to Older Sibling's Teacher", size(medsmall)) ytitle("Density", size(medsmall)) ///
	xline(`match_tch`tch'') xscale(range(`scalemin' `scalemax')) xlabel(`labmin' (0.01) `labmax', labsize(small))
graph export "$figures/Actual/0`tch'_`tch'Tch.pdf", replace 
}

**Student Race**
foreach race in White Black Hispanic Other {
quietly summ frac_os_`race'
local varmin = r(min)
local varmin = round(`varmin',0.001)
local varmax = r(max)
local varmax = round(`varmax',0.001)
local scalemin = `varmin' - 0.005
local scalemax = cond(`varmax' > `match_`race'', `varmax' + 0.005, `match_`race'' + 0.005)
local labmin = `scalemin' + 0.003
local labmax = `scalemax' - 0.003

kdensity frac_os_`race', kernel(gaus) legend(off) ///
	title("`race' Students") ///
	xtitle("Share Assigned to Older Sibling's Teacher", size(medsmall)) ytitle("Density", size(medsmall)) ///
	xline(`match_`race'') xscale(range(`scalemin' `scalemax')) xlabel(`labmin' (0.01) `labmax', labsize(small))
graph export "$figures/Actual/06_Race`race'.pdf", replace
}


**Student Characteristics**
quietly summ frac_os_eds0
local varmin = r(min)
local varmin = round(`varmin',0.001)
local varmax = r(max)
local varmax = round(`varmax',0.001)
local scalemin = `varmin' - 0.005
local scalemax = cond(`varmax' > `match_eds0', `varmax' + 0.005, `match_eds0' + 0.005)
local labmin = `scalemin' + 0.003
local labmax = `scalemax' - 0.003

kdensity frac_os_eds0, kernel(gaus) legend(off) ///
	title("Non-poor Students") ///
	xtitle("Share Assigned to Older Sibling's Teacher", size(medsmall)) ytitle("Density", size(medsmall)) ///
	xline(`match_eds0') xscale(range(`scalemin' `scalemax')) xlabel(`labmin' (0.01) `labmax', labsize(small))
graph export "$figures/Actual/07_eds0.pdf", replace

quietly summ frac_os_eds1
local varmin = r(min)
local varmin = round(`varmin',0.001)
local varmax = r(max)
local varmax = round(`varmax',0.001)
local scalemin = `varmin' - 0.005
local scalemax = cond(`varmax' > `match_eds1', `varmax' + 0.005, `match_eds1' + 0.005)
local labmin = `scalemin' + 0.003
local labmax = `scalemax' - 0.003

kdensity frac_os_eds1, kernel(gaus) legend(off) ///
	title("Poor Students") ///
	xtitle("Share Assigned to Older Sibling's Teacher", size(medsmall)) ytitle("Density", size(medsmall)) ///
	xline(`match_eds1') xscale(range(`scalemin' `scalemax')) xlabel(`labmin' (0.01) `labmax', labsize(small))
graph export "$figures/Actual/08_eds1.pdf", replace

quietly summ frac_os_preread_gtm0
local varmin = r(min)
local varmin = round(`varmin',0.001)
local varmax = r(max)
local varmax = round(`varmax',0.001)
local scalemin = `varmin' - 0.005
local scalemax = cond(`varmax' > `match_preread_gtm0', `varmax' + 0.005, `match_preread_gtm0' + 0.005)
local labmin = `scalemin' + 0.003
local labmax = `scalemax' - 0.003

kdensity frac_os_eds0, kernel(gaus) legend(off) ///
	title("Low Achieving Students") ///
	xtitle("Share Assigned to Older Sibling's Teacher", size(medsmall)) ytitle("Density", size(medsmall)) ///
	xline(`match_preread_gtm0') xscale(range(`scalemin' `scalemax')) xlabel(`labmin' (0.01) `labmax', labsize(small))
graph export "$figures/Actual/09_preread_gtm0.pdf", replace

quietly summ frac_os_preread_gtm1
local varmin = r(min)
local varmin = round(`varmin',0.001)
local varmax = r(max)
local varmax = round(`varmax',0.001)
local scalemin = `varmin' - 0.005
local scalemax = cond(`varmax' > `match_preread_gtm1', `varmax' + 0.005, `match_preread_gtm1' + 0.005)
local labmin = `scalemin' + 0.003
local labmax = `scalemax' - 0.003

kdensity frac_os_eds0, kernel(gaus) legend(off) ///
	title("High-Achieving Students") ///
	xtitle("Share Assigned to Older Sibling's Teacher", size(medsmall)) ytitle("Density", size(medsmall)) ///
	xline(`match_preread_gtm1') xscale(range(`scalemin' `scalemax')) xlabel(`labmin' (0.01) `labmax', labsize(small))
graph export "$figures/Actual/10_preread_gtm1.pdf", replace


**Teacher Characteristics**
quietly summ frac_os_expgt3i0
local varmin = r(min)
local varmin = round(`varmin',0.001)
local varmax = r(max)
local varmax = round(`varmax',0.001)
local scalemin = `varmin' - 0.005
local scalemax = cond(`varmax' > `match_expgt3i0', `varmax' + 0.005, `match_expgt3i0' + 0.005)
local labmin = `scalemin' + 0.003
local labmax = `scalemax' - 0.003

kdensity frac_os_expgt3i0, kernel(gaus) legend(off) ///
	title("Teacher Experience < 3 Years") ///
	xtitle("Share Assigned to Older Sibling's Teacher", size(medsmall)) ytitle("Density", size(medsmall)) ///
	xline(`match_expgt3i0') xscale(range(`scalemin' `scalemax')) xlabel(`labmin' (0.01) `labmax', labsize(small))
graph export "$figures/Actual/11_expgt3i0.pdf", replace

quietly summ frac_os_expgt3i1
local varmin = r(min)
local varmin = round(`varmin',0.001)
local varmax = r(max)
local varmax = round(`varmax',0.001)
local scalemin = `varmin' - 0.005
local scalemax = cond(`varmax' > `match_expgt3i1', `varmax' + 0.005, `match_expgt3i1' + 0.005)
local labmin = `scalemin' + 0.003
local labmax = `scalemax' - 0.003

kdensity frac_os_expgt3i1, kernel(gaus) legend(off) ///
	title("Teacher Experience >= 3 Years") ///
	xtitle("Share Assigned to Older Sibling's Teacher", size(medsmall)) ytitle("Density", size(medsmall)) ///
	xline(`match_expgt3i1') xscale(range(`scalemin' `scalemax')) xlabel(`labmin' (0.01) `labmax', labsize(small))
graph export "$figures/Actual/12_expgt3i1.pdf", replace

quietly summ frac_os_more_than_BA0
local varmin = r(min)
local varmin = round(`varmin',0.001)
local varmax = r(max)
local varmax = round(`varmax',0.001)
local scalemin = `varmin' - 0.005
local scalemax = cond(`varmax' > `match_more_than_BA0', `varmax' + 0.005, `match_more_than_BA0' + 0.005)
local labmin = `scalemin' + 0.003
local labmax = `scalemax' - 0.003

kdensity frac_os_more_than_BA0, kernel(gaus) legend(off) ///
	title("Teacher does not have Advanced Degree") ///
	xtitle("Share Assigned to Older Sibling's Teacher", size(medsmall)) ytitle("Density", size(medsmall)) ///
	xline(`match_more_than_BA0') xscale(range(`scalemin' `scalemax')) xlabel(`labmin' (0.01) `labmax', labsize(small))
graph export "$figures/Actual/13_more_than_BA0.pdf", replace

quietly summ frac_os_more_than_BA1
local varmin = r(min)
local varmin = round(`varmin',0.001)
local varmax = r(max)
local varmax = round(`varmax',0.001)
local scalemin = `varmin' - 0.005
local scalemax = cond(`varmax' > `match_more_than_BA1', `varmax' + 0.005, `match_more_than_BA1' + 0.005)
local labmin = `scalemin' + 0.003
local labmax = `scalemax' - 0.003

kdensity frac_os_more_than_BA1, kernel(gaus) legend(off) ///
	title("Teacher has Advanced Degree") ///
	xtitle("Share Assigned to Older Sibling's Teacher", size(medsmall)) ytitle("Density", size(medsmall)) ///
	xline(`match_more_than_BA1') xscale(range(`scalemin' `scalemax')) xlabel(`labmin' (0.01) `labmax', labsize(small))
graph export "$figures/Actual/14_more_than_BA1.pdf", replace

quietly summ frac_os_nbpts0
local varmin = r(min)
local varmin = round(`varmin',0.001)
local varmax = r(max)
local varmax = round(`varmax',0.001)
local scalemin = `varmin' - 0.005
local scalemax = cond(`varmax' > `match_nbpts0', `varmax' + 0.005, `match_nbpts0' + 0.005)
local labmin = `scalemin' + 0.003
local labmax = `scalemax' - 0.003

kdensity frac_os_nbpts0, kernel(gaus) legend(off) ///
	title("Teacher is not National Board Certified") ///
	xtitle("Share Assigned to Older Sibling's Teacher", size(medsmall)) ytitle("Density", size(medsmall)) ///
	xline(`match_nbpts0') xscale(range(`scalemin' `scalemax')) xlabel(`labmin' (0.01) `labmax', labsize(small))
graph export "$figures/Actual/15_nbpts0.pdf", replace

quietly summ frac_os_nbpts1
local varmin = r(min)
local varmin = round(`varmin',0.001)
local varmax = r(max)
local varmax = round(`varmax',0.001)
local scalemin = `varmin' - 0.005
local scalemax = cond(`varmax' > `match_nbpts1', `varmax' + 0.005, `match_nbpts1' + 0.005)
local labmin = `scalemin' + 0.003
local labmax = `scalemax' - 0.003

kdensity frac_os_nbpts1, kernel(gaus) legend(off) ///
	title("Teacher is National Board Certified") ///
	xtitle("Share Assigned to Older Sibling's Teacher", size(medsmall)) ytitle("Density", size(medsmall)) ///
	xline(`match_nbpts1') xscale(range(`scalemin' `scalemax')) xlabel(`labmin' (0.01) `labmax', labsize(small))
graph export "$figures/Actual/16_nbpts1.pdf", replace

quietly summ frac_os_va_gtm0
local varmin = r(min)
local varmin = round(`varmin',0.001)
local varmax = r(max)
local varmax = round(`varmax',0.001)
local scalemin = `varmin' - 0.005
local scalemax = cond(`varmax' > `match_va_gtm0', `varmax' + 0.005, `match_va_gtm0' + 0.005)
local labmin = `scalemin' + 0.003
local labmax = `scalemax' - 0.003

kdensity frac_os_va_gtm0, kernel(gaus) legend(off) ///
	title("Teacher is Low Value-Added") ///
	xtitle("Share Assigned to Older Sibling's Teacher", size(medsmall)) ytitle("Density", size(medsmall)) ///
	xline(`match_va_gtm0') xscale(range(`scalemin' `scalemax')) xlabel(`labmin' (0.01) `labmax', labsize(small))
graph export "$figures/Actual/17_va_gtm0.pdf", replace

quietly summ frac_os_va_gtm1
local varmin = r(min)
local varmin = round(`varmin',0.001)
local varmax = r(max)
local varmax = round(`varmax',0.001)
local scalemin = `varmin' - 0.005
local scalemax = cond(`varmax' > `match_va_gtm1', `varmax' + 0.005, `match_va_gtm1' + 0.005)
local labmin = `scalemin' + 0.003
local labmax = `scalemax' - 0.003

kdensity frac_os_va_gtm1, kernel(gaus) legend(off) ///
	title("Teacher is High Value-Added") ///
	xtitle("Share Assigned to Older Sibling's Teacher", size(medsmall)) ytitle("Density", size(medsmall)) ///
	xline(`match_va_gtm1') xscale(range(`scalemin' `scalemax')) xlabel(`labmin' (0.01) `labmax', labsize(small))
graph export "$figures/Actual/18_va_gtm1.pdf", replace


