
clear all
version 12
set more off
cap log close

do "/home/home2/qureshi_rs1/teacher_sorting/directory_do"

*This do file creates i) a student-year level dataset with reading observations in grades 4+5 in regular classes
*and ii) a dataset with all available reading teachers in each school-grade-year

*i) 
cd "$data"
use VAM_data.dta, clear

g m_teachid = teachid if math_subj==1
bys mastid year: egen mteachid = max(m_teachid) /*verified there's only one mteachid per child so this is fine*/
drop m_teachid

*keep read observations
keep if read_subj==1

*****************************
*STEP 1:duplicates		
******************************

g read_mis = read==.
bys mastid year: egen read1 = min(read_mis)
bys mastid year: egen read2 = max(read_mis)
count if read1!=read2
drop if read==. & read1!=read2
drop read1 read2

sort mastid year teachid coursetitle
qui by mastid year teachid coursetitle:  gen dup1 = cond(_N==1,0,_n)
drop if dup1>0
drop dup1

* If teachid is the same but coursetitle is diff
sort mastid year teachid
qui by mastid year  teachid:  gen dup1 = cond(_N==1,0,_n)
bys mastid year: egen teachid1 = min(teachid)
bys mastid year: egen teachid2 = max(teachid)
count if teachid1!=teachid2 
g teachid_mis = teachid==.

encode coursetitle, gen(coursetitlen)
bys mastid year: egen coursetitle1 = min(coursetitlen)
bys mastid year: egen coursetitle2 = max(coursetitlen)
count if dup1>0
count if coursetitle1!=coursetitle2 & dup1>0 /*All of duplicates are due to different coursetitles*/
tab dup1 if coursetitlen==coursetitle1 
keep if coursetitlen==coursetitle1 

tab dup1
sort mastid year teachid
qui by mastid year  teachid:  gen dup1b = cond(_N==1,0,_n)
*No more duplicates
drop dup1 dup1b

sort mastid year 
qui by mastid year  :  gen dup = cond(_N==1,0,_n)
tab dup
drop dup

**********************************
*STEP 2*
*Create indicators for whether students' teacher is teaching <10 | >50 students or their teacher is teaching more than 25% disabled students 
*Create nstudt taught by each teacher
bys schgryr teachid: gen nstudt = _N
g dropclass1 = nstudt<10 | nstudt>50 
g dropclass1a = nstudt<10
g dropclass1b = nstudt>50
tab dropclass1

egen pctdis_class =mean(disabled), by(schgryr teachid)
g dropclass2 = pctdis_class>0.25 
tab dropclass2

lab var dropclass1 "Teacher has <10 or >50 students in sgy"
lab var dropclass2 "Teacher has >25% disabled students in sgy"

egen avgscore = rowmean(read math)
bys grade: egen mavgscore = median(avgscore)
tab mavgscore if grade==3
tab mavgscore if grade==4
tab mavgscore if grade==5

****************************************************************************
cd "$data"
save readdata_rr.dta, replace 
/*This student-level data keeps reading observations for grades 4+5 in the regular classes */
*****************************************************************************************************************
*ii)
*Create nstud in sgy
bys schgryr: gen nstud = _N
g propst = nstudt/nstud

keep schlcode_fl lea_r grade year schgryr teachid propst nstudt nstud 
*Now go from student-level data to teacher-level data
duplicates drop 
bys schgryr: egen ntchinsgy = count(teachid)
lab var ntchinsgy "# tchrs in sgy"

sort lea_r schlcode_fl grade year teachid 
cd "$data"
save tchsgydata_rr.dta, replace 
*************************************************************

cd "$data"
use readdata_rr.dta, clear

drop if dropclass1a == 1
drop dropclass1a dropclass1b

*ii)
*Create nstud in sgy
bys schgryr: egen nstud_1a = count(mastid)
lab var nstud_1a "Number of students in SGY, excluding classes < 10"

g propst_1a = nstudt/nstud_1a
lab var propst_1a "Share of students taught by tch, excluding classes < 10"

keep schlcode_fl lea_r grade year schgryr teachid nstudt dropclass1 dropclass2 nstud_1a propst_1a
*Now go from student-level data to teacher-level data

duplicates drop 
bys schgryr: egen ntchinsgy_1a = count(teachid)
lab var ntchinsgy_1a "# tchrs in sgy, excluding classes < 10"

sort lea_r schlcode_fl grade year teachid 
cd "$data"
save tchsgydata_rr_1a.dta, replace 





