clear all
version 13
set more off
do "/home/home2/qureshi_rs1/teacher_sorting/directory_do"


cd $logs 
log using 3b_read_math_elem_middles_clean, replace


/* 
	INPUT:  2crs_memb2007_2012.dta
		3crs_memb2007_2012.dta 
		4crs_memb2007_2012.dta

	
	OUTPUT: 3crs_memb2007_2012.dta
	4crs_memb2007_2012_gr3_8.dta
	5crs_memb2007_2014.dta
	6crs_memb2007_2012.dta
01_math_read_classes.dta	
*/

cd $data

use  2crs_memb2007_2012.dta, clear

drop meetingcode sex ethnic american_indian ///
     asian hispanic black white multi_race pacific_islander dup1a dup1b dup2a ///
     dup2b dup3a dup3b
     
keep if grade==3| grade==4 | grade==5 | grade==6| grade==7 | grade==8

sort mastid lea_r schlcode_fl grade year coursetitle section semester collection_code teachid

duplicates drop mastid lea_r schlcode_fl grade year coursetitle section semester collection_code teachid, force
tab dup5a if teachid==.     
gen miss_teach1=1 if dup5a!=. & teachid==.
	label var miss_teach1 "tracks if teacher is missing for students in years <2009"
	
gen dup_miss_teach1=1 if dup5a==1 & teachid==. | dup5a==2 & teachid==. | dup5a==3 & teachid==.
	label var dup_miss_teach1 "tracks if teacher is missing for duplicates of students in a class in years <2009"
	
gen dup_teach1=1 if dup5a==1 & teachid!=. | dup5a==2 & teachid!=. | dup5a==3 & teachid!=.
	label var dup_teach1 "tracks students that are duplicates in a class and have teachid"
	
egen dup_xteach1= max(dup_teach1) if dup5a==1 | dup5a==2 | dup5a==3 ,by(mastid lea_r schlcode_fl grade year coursetitle section semester)
	
drop if dup5a>0 & dup5a!=. & teachid==. & dup_xteach1==1

duplicates report mastid lea_r schlcode_fl grade year coursetitle section semester if year<2009
duplicates report mastid lea_r schlcode_fl grade year coursetitle section semester teachid if year<2009
duplicates tag mastid lea_r schlcode_fl grade year coursetitle section semester if year<2009, gen(dup6a)
	label var dup6a "tracks duplicates of students with more then one teacher in class year<2009"	

drop if teachid==. & year<2009	
	tab dup5b
tab dup5b if teachid==.
drop if teachid==. & year>2008	

duplicates tag mastid lea_r schlcode_fl grade year coursetitle section semester teachid if year>2008, gen(dup6b)
label var dup6b "tracks duplicates in a class with same teacher where collection_code varies"

tab dup6b


duplicates report mastid lea_r schlcode_fl grade year coursetitle section semester if year>2008
duplicates tag mastid lea_r schlcode_fl grade year coursetitle section semester if year>2008, gen(dup7b)
	label var dup7b "duplicates of student in class because of multiple teachers"
	
drop dup4a dup4b dup5a dup5b miss_teach1 dup_miss_teach1 dup_teach1 dup_xteach1 dup6b

cd $data
cd coursemembership
save 3crs_memb2007_2012.dta,replace

**********************************************************************************
********************Tracking Math and Reading courses*****************************
**********************************************************************************
cd $data
cd coursemembership
use 3crs_memb2007_2012.dta
replace coursetitle=lower(coursetitle)

*math course
gen math_class    =regexm(coursetitle,"math") 
foreach x in "algebra" "pre alegbra" "geom" "stati" "arith" "mat" "alge" "pre-alg" "alg" ///
             "precalculus" "albebra" "calculus" "numeracy" "advance sixth grade ma" ///
	     	 "magnet number theory i" "magnet brain games" "magnet financial finesse" ///
	     	 "brainteasers" "number crunching" "logic & problem solvin" "brain teasers" ///
	     	 "prob & stats" "count it out" "albegra" "pre-calculus"{
      replace math_class= regexm(coursetitle, "`x'") if math_class==0
      }
 
foreach x in "pltw automation and robotics" "dramatic" "magnet grey matter" ///
	     	 "magnet greymatter" "information skills" "automation & robotics" "dramataics" ///
	    	 "flow of matter" {      
replace math_class=0 if regexm(coursetitle, "`x'")>0 & math_class==1
}      
gen math_type=1 if math_class==1 

bysort mastid year lea_r schlcode_fl: gen inter=_n
egen   math_m_class=max(math_class), by(mastid year lea_r schlcode_fl)

egen    num_courses=count(mastid) if math_m_class==0, by(mastid year lea_r schlcode_fl)

replace math_class=1 if num_courses==1
replace math_type=2  if num_courses==1

drop math_m_class

egen math_m_class=max(math_class), by(mastid year lea_r schlcode_fl)
tab math_m_class

*self contained
gen math_class1=0 if math_m_class==0

foreach x in "self-cont" "self contained" "selfcontained" "sef" "0000self" "0000 s" "self-contained" "self contained" ///
             "self - con" "self coun" "self- con" "elementary curri" "contain"  ///
	     	 "ec sc class" "self -con" "self-con" "5 00 elementary self c" ///
	     	 "32 0 block k-5 self-co" "self con" "18 0 cross cat self co" ///
	     	 "13 0sc" "11 0 cross cat self co" "0000sc" "0000bls-sc" ///
	     	 "0000-fourth grade self" "0000-fifth grade self" "0000-ex. children self " ///
	     	 "0000-cross cat self co" "0000 fifth grade self-" "0000 block k-6 self-co" ///
	     	 "0000 autistic self-con" "0000 all elementary su" "0000 all day all subje " ///
	     	 "0000 all day" "0000 5th grade self co" "0000 4th grade self co" "0000 4th gr self conta" ///
	     	 "0000 2-3 self-con" "0000" "self cont" {
	replace math_class1=1 if regexm(coursetitle,"`x'")>0 & math_class1==0 
	}
egen sc_count=total(math_class1) if math_m_class==0, by(mastid year lea_r schlcode_fl)
	
replace math_class=1 if math_class1==1 & sc_count==1
replace math_type=3  if math_class1==1 & sc_count==1
tab coursetitle if math_class1==1 & sc_count>1 & sc_count!=.
	
foreach x in    "phys education self con" "music self con" "homeroom 5 ec self-con" ///
				"art self contained" "0000music" "0000physical education" "music self contained" ///
				"phys education self contained" "reading/self contained" "science/self contained" ///
				"0000art class"  {
	replace math_class1=0 if regexm(coursetitle, "`x'")>0 & math_class1==1 & sc_count>1 & sc_count!=.
	}

replace math_type=4 if math_class1==1 &  sc_count>1 & sc_count!=.
replace math_class=1 if math_class1==1

drop math_class1 math_m_class

egen math_m_class=max(math_class), by(mastid year lea_r schlcode_fl)
tab  math_m_class if inter==1

label var math_type "categorizes how math classes were classified"
label define type 1 "course title was directly linked to subject" 2 "only class specified for student" ///
                  3 "course title contains self contained and is the only as such" ///
                  4 "course title contains self contained either alone or coupled with reading"
                  
label values math_type type

sort mastid lea_r schlcode_fl grade year coursetitle semester section teachid collection_code math_class

duplicates report mastid lea_r schlcode_fl grade year coursetitle semester section teachid collection_code if math_class==1
duplicates drop mastid lea_r schlcode_fl grade year coursetitle semester section teachid collection_code if math_class==1, force
 
*reading course
gen     read_class= regexm(coursetitle,"english")  
foreach x in    "eng" "engli" "language art" "grammar"  ///
		"read" "journal" "literature" "humanities" "spelling" "writing"   ///
		"written" "uage arts" "3rd grade language/wri" "language-arts"  ///
		"6th grade adv. languag" "6th grade advance lang" "ela" "wri" "lang art"  ///
		"l.a." "language ar" "literacy" "7th advanced lang" "7th grade adv. languag"  ///
		"mmunic" "esl" "gramar" "7th grade language" "7th honors la" "language ar"  ///
		"8th grade language" "accelerated language a" "accelerated middle school langua"  ///
		"lang. arts" "ag 5th grade la" "critical thinking" "lang/art" "ec lang" "ec/la"  ///
		"eclang" "eighth grade language" "emh language" "emh/ld grade 3 languag" "emh/ld grade 4 languag"  ///
		"emh/ld grade 5 languag" "encore language" "enlish" "exceptional ch languag"  ///
		"exceptional language a" "greek and roman myth" "harry potter" "standard plus language"  ///
		"exploratory language" "language" "r-fluency" "r-compren." "magnet ib l arts elective "  ///
		"academically gifted en" "language third grade" "classical mythology" "language/arts"  ///
		"spec int lang" "lang 8" "short stories" "language grade 4" "language 5" "6th grade language"  ///
		"magnet folk tales & myths" "mythology" "poetry" "non-fiction studies" "literary styles"  ///
		"lang.arts" "storytelling" "once upon a time" "wonderful words" "language/wri"  ///
		"folk tales" "novel study" "word power" "mystery&suspense" "21 rd grade language a"  ///
		"story cornucopia" "great books i" "guage arts" "lang. arts" "5th grade remedial rea"  ///
		"honors language a" "pre college language a" "4th grade remedial rea" "phenomenon of language" ///
		"critical thnkg" "la/ss" "lang/spell" "langartsx" "languagearts" "lng arts" "grade remedial rea" ///
		"novel st." "la 7-8" "novel studies" "storyboard" "language academically" "linguistics" ///
		"language/ss (6-8)" "language/social" "cultural lit" "vocabulary" "lang/ar" ///
		"novel stars" "hit those books" "lang  arts" "languarge arts" "lit & traditions thru holidays" ///
		"uage arts" "battle of the books" "language enrichment" "developmental language" "language/ss" ///
		"languare arts" "lanugage arts" "storytellingmed" "enlish" "wrwiting" "languag arts" ///
		"la elementary" "la resource weekly" "la/math aig" "la/math" "la/sci" "lang/math" ///
		"langarts" "langauge art" "language arts" "lang arts/math/science" "8th grade adv. languag" ///
		"8th grade advance lang" "8th grade la aig" "8th grade la individua" "7th grade la individua" ///
		"fantasy & science fict" "la 7 enrichment" "la adv" "la ec 8th grade" "la gr 6" "la resource" ///
		"la self contained all" "la-7 ec" "la-7-ec-sc" "la-sixth ec-self con." "la/arts" "lang 6" ///
		"lang 7" "langage arts" "lep-7 level iii langua" "lep-8 level ii languag" "magnet  advance langua" ///
		"magnet science fiction" "magnetsciencefiction" "languauge art" "self contained-lang ar" ///
		"self-contained languag" "lang alive" "special education lang"{ 
      replace read_class= regexm(coursetitle, "`x'") if read_class==0
      }

foreach x in "4th grade - visual art" "visual art" "general art" "transitional algebra" ///
         "computer literacy" "teen leaders" "leadership seminar" "additional comments" ///
         "aig-language grade 5" " aig-language sixth gra" "applied engineering spec intrst" ///
         "art: australian" "broadcast journalism" "career explrations" "ccr language" ///
         "challenge social studi" "cherokee language" "chinese" "japan" "german" "french" ///
         "dramatics" "film literacy" "financial literacy" "cultural art" "design & eng" ///
         "cursive writing" "arabic" "communities" "community" "compass learning"  ///
 		 "computer learing lab" "consultative" "creative academic learning lab"   ///
 		 "critical thinking" "cul arts & hsptity" "cultural art" "digital applications" ///
 		 "ec lang" "eight grade high school algebra" "eighth grade language" "engineering" ///
 		 "esl math" "esl science" "esl social studies" "exploratory   language" ///
 		 "exploratory foreign language" "exploring foreign language" "exploring language" ///
 		 "fast forword nine week learning" "fast forword semester learning l"   ///
 		 "fast math" "fifth grade language" "film as literature" "fitness/sports literacy" ///
 		 "foreign language" "french: humanities" "functional academics" "future ready/avid" ///
 		 "general assistant" "general comments" "global awareness/ce" "global leadership" ///
 		 "handwriting" "greek and roman" "h writing" "hand writing" "hardwriting" "health" ///
 		 "high school algebra" "i can learn math" "indiv curriculum -lear"  ///
 		 "indiv curriculum -learn lab -acc" "industrial arts" "keyboard/typewriting" ///
 		 "leader in me" "leadership" "learner's enriched mat" "learning disabilities" ///
 		 "learning disabled" "learning lab" "learning strategies" "learning to succeed" ///
 		 "literacy and technolog" "lunch/physical" "commercial art" "common sense chemistry" ///
 		 "expl art throug" "intl relations" "learn about you" "robo challenge" "robochallenge" ///
 		 "ld ballgame" "middle school algebra" " middle school art" "learning seminar" ///
 		 "music/health-pe/spanish/" "music/hlth-pe/spanish/" "music/pe/leadership/" ///
 		 "other foreign language" "outdoor leadership" "pe-health/" "pe-hlth/" "pe/leadership/" ///
 		 "physical activity" "public school art" " ready set sew!" "regional arts" ///
 		 " remedial math (esl-ms)" "science esl 3rd grade" "science esl 4th grade" "science literacy" ///
 		 "science/esl" "second language" "service learning" "sign language" "visual literacy" ///
 		 "small engines" "social/adaptive" "cultural lit" "sp/lead/music/" "cultural arts"  ///
 		 "strength & conditioning" "strength training" "student leadership" "synergistic learning lab" ///
 		 "talking/engergizing &" "technology leadership " "teen alliance" "teen leadership" ///
 		 "theatrical art " "thinking skills" "transitional algebra" "viaual arts" "video literature" ///
 		 "visial art" "visiual art" "win-let's go learn " "win-reading/film" "world languages" ///
 		 "year long middle school art" {
		replace read_class=0 if regexm(coursetitle, "`x'")==1 & read_class==1
		}
	
gen read_type=1 if read_class==1

egen   read_m_class=max(read_class), by(mastid year lea_r schlcode_fl)
tab    read_m_class if inter==1

egen    rnum_courses=count(mastid) if read_m_class==0, by(mastid year lea_r schlcode_fl)

replace read_class=1 if rnum_courses==1
replace read_type=2  if rnum_courses==1

drop read_m_class
egen read_m_class=max(read_class), by(mastid year lea_r schlcode_fl)
tab  read_m_class if inter==1

*selfcontained
gen read_class1=0 if read_m_class==0

foreach x in "self-cont" "self contained" "selfcontained" "sef" "0000self" "0000 s" "self-contained" "self contained" ///
             "self - con" "self coun" "self- con" "elementary curri" "contain"  ///
	     	 "ec sc class" "self -con" "self-con" "5 00 elementary self c" ///
	     	 "32 0 block k-5 self-co" "self con" "18 0 cross cat self co" ///
	     	 "13 0sc" "11 0 cross cat self co" "0000sc" "0000bls-sc" ///
	     	 "0000-fourth grade self" "0000-fifth grade self" "0000-ex. children self " ///
	     	 "0000-cross cat self co" "0000 fifth grade self-" "0000 block k-6 self-co" ///
	     	 "0000 autistic self-con" "0000 all elementary su" "0000 all day all subje " ///
	     	 "0000 all day" "0000 5th grade self co" "0000 4th grade self co" "0000 4th gr self conta" ///
	     	 "0000 2-3 self-con" "0000" "self cont" {
	replace read_class1=1 if regexm(coursetitle,"`x'")>0 & read_class1==0 
	}
egen rsc_count=total(read_class1) if read_m_class==0, by(mastid year lea_r schlcode_fl)

replace read_class=1 if read_class1==1 & rsc_count==1
replace read_type=3  if read_class1==1 & rsc_count==1
tab coursetitle if read_class1==1 & rsc_count>1 & rsc_count!=.
	
foreach x in  "phys education self con" "music self con" "homeroom 5 ec self-con" ///
		"art self contained" "0000music" "0000physical education" "music self contained" ///
		"phys education self contained" "science/self contained" "math/self contained" ///
		"0000art class"  {
	replace read_class1=0 if regexm(coursetitle, "`x'")>0 & read_class1==1 & rsc_count>1 & rsc_count!=.
	}

replace read_type=4  if read_class1==1 & rsc_count>1 & rsc_count!=.
replace read_class=1 if read_class1==1

drop read_class1 read_m_class
egen read_m_class=max(read_class), by(mastid year lea_r schlcode_fl)
tab  read_m_class if inter==1

label var read_type "categorize how reading classes were classified"
label values read_type type

sort mastid lea_r schlcode_fl grade year coursetitle semester section teachid collection_code read_class

duplicates report mastid lea_r schlcode_fl grade year coursetitle semester section teachid collection_code if read_class==1
duplicates drop mastid lea_r schlcode_fl grade year coursetitle semester section teachid collection_code  if read_class==1, force

 
gen subject_id=substr(statecourse,1,4)
gen subject_id_2=substr(subject_id,1,2)

gen math_subj=regexm(subject_id_2,"20")

foreach x in "0123" "0230" "0423" "0120" "0124" "0420" "0239" "0129" "0290" {
	replace math_subj=1 if regexm(subject_id,"`x'")>0 & math_subj!=1
	}
	
gen read_subj=regexm(subject_id_2,"01")

foreach x in "1010" "1022" "1024" "1026" "1028" "1033" "1035" "1038" ///
             "1001" "1021" "1023" "1025" "1027" "1029" "1034" "1036" {
	replace read_subj=1 if regexm(subject_id,"`x'")>0 & read_subj!=1
	}
	
gen mtype=1 if math_subj==1
gen rtype=1 if read_subj==1	
	
	
egen xmath=max(math_subj), by(mastid year)
egen xread=max(read_subj), by(mastid year)

bysort mastid year: gen stud_yr=_n

tab xmath if stud_yr==1
tab xread if stud_yr==1

replace math_subj=1 if regexm(subject_id,"0000")>0 & math_subj!=1 & xmath==0
replace read_subj=1 if regexm(subject_id,"0000")>0 & read_subj!=1 & xread==0

replace mtype=2 if math_subj==1 & xmath==0
replace rtype=2 if read_subj==1 & xread==0

drop xmath xread 
	 
egen xmath=max(math_subj), by(mastid year)
egen xread=max(read_subj), by(mastid year)

tab xmath if stud_yr==1
tab xread if stud_yr==1

tab math_subj math_class
tab read_subj read_class


*Categorzing courses into subjects:

	gen     subject="self-contained" if subject_id=="0000"
	replace subject="reading"        if subject_id=="1001"
	replace subject="language arts"  if subject_id=="1010"

forvalues i=1/4{ 
	replace subject="english `i'"    if subject_id=="102`i'"
	}
	
	replace subject="english language & composition"   if subject_id=="1035"
	replace subject="english literature & composition" if subject_id=="1036"
	replace subject="english as a second language"     if subject_id=="1038"
	replace subject="math (k-8)" 					   if subject_id=="2001"
	replace subject="accelerated middle school math"   if subject_id=="2003"
	replace subject="fundamental math 1"		  	   if subject_id=="2008"
	replace subject="fundamental math 2"		   	   if subject_id=="2009"
	replace subject="technical math 1"			       if subject_id=="2015"
	replace subject="technical math 2"				   if subject_id=="2017"
	replace subject="math and other"				   if subject_id=="0230" | subject_id=="0423" ///
													   | subject_id=="0420" | subject_id=="0239" ///
													   | subject_id=="0290"
	replace subject="language and other"			   if subject_id=="0130" | subject_id=="0140" ///
														|  subject_id=="0109"
	replace subject="language arts/math/other"		   if subject_id=="0120" | subject_id=="0123" ///
														 | subject_id=="0124" | subject_id=="0129"
	
	
forvalues i=1025/1029{
	replace subject="special interest language"       if subject_id=="`i'"
	}
	
replace subject="literature"						  if subject_id=="1033" | subject_id=="1034"
replace subject="algebra 1"							  if subject_id=="2018" | subject_id=="2021" ///
														| subject_id=="2022" | subject_id=="2023"
replace subject="algebra 2"							  if subject_id=="2024"
replace subject="algebra 3"						      if subject_id=="2019" | subject_id=="2025"
replace subject="geometry and trigonometry"			  if subject_id=="2029" | subject_id=="2030" ///
                                                       | subject_id=="2041" | subject_id=="2031"
replace subject="probability statistics"              if subject_id=="2065" | subject_id=="2066"
replace subject="other math topics"		              if subject_id=="2020" | subject_id=="2050" ///
													   | subject_id=="2063"
replace subject="applied math 1"					  if subject_id=="2026"
replace subject="applied math 2"					  if subject_id=="2027"

forvalues i=1/4{
	replace subject="integrated math `i'"             if subject_id=="205`i'"
	}
	
	replace subject="integrated math 1"				  if subject_id=="2055"
	replace subject="integrated math 2"				  if subject_id=="2056"
	replace subject="integrated math 3"               if subject_id=="2057"
	replace subject="math ib 1"						  if subject_id=="2081" | subject_id=="2071" | subject_id=="2078"
	replace subject="math ib 2"						  if subject_id=="2072" | subject_id=="2074" | subject_id=="2079"
	replace subject="math ib 3"						  if subject_id=="2080"
	replace subject="ap calculus"					  if subject_id=="2077" | subject_id=="2076"
	replace subject="pre-calculus"					  if subject_id=="2070"
	replace subject="fifth year math"				  if subject_id=="2073" 
                                                       
                                                       
tab subject if math_subj==1
tab subject if read_subj==1

*num courses	
bysort math_subj mastid year subject semester: gen m_course=_n if math_subj==1
bysort read_subj mastid year subject semester: gen r_course=_n if read_subj==1

egen mcou_num  =total(m_course) if m_course==1 & math_subj==1, by(mastid year semester)
egen mcrs_num  =max(mcou_num)   if math_subj==1, by(mastid year semester)
gen  has_mult_m=(mcrs_num>1)    if math_subj==1 & !missing(mcrs_num)

egen rcou_num  =total(r_course) if r_course==1 & read_subj==1, by(mastid year semester)
egen rcrs_num  =max(rcou_num)   if read_subj==1, by(mastid year semester)
gen  has_mult_r=(rcrs_num>1)    if read_subj==1 & !missing(rcrs_num)

drop m_course r_course

*multiple course
bysort math_subj mastid year subject_id semester: gen mm_course=_n if math_subj==1
bysort read_subj mastid year subject_id semester: gen rr_course=_n if read_subj==1

egen mmcou_num  =total(mm_course) if mm_course==1 & math_subj==1, by(mastid year semester)
egen mmcrs_num  =max(mm_course)   if math_subj==1, by(mastid year semester)
gen  has_mult_mm=(mmcrs_num>1)    if math_subj==1 & !missing(mmcrs_num)

egen rrcou_num  =total(rr_course) if rr_course==1 & read_subj==1, by(mastid year semester)
egen rrcrs_num  =max(rrcou_num)   if read_subj==1, by(mastid year semester)
gen  has_mult_rr=(rrcrs_num>1)    if read_subj==1 & !missing(rrcrs_num)

bysort math_subj mastid year semester: gen m_course=_n if math_subj==1
bysort read_subj mastid year semester: gen r_course=_n if read_subj==1

*Multiple math/read
bysort grade: tab has_mult_mm if m_course==1
bysort grade: tab has_mult_rr if r_course==1		
bysort grade: tab has_mult_m if m_course==1
bysort grade: tab has_mult_r if r_course==1

cd $data
cd coursemembership
save 4crs_memb2007_2012.dta, replace

cd $data
cd coursemembership
use 4crs_memb2007_2012.dta

drop mcou_num rcou_num mm_course mmcou_num rrcou_num
keep if math_subj==1 | read_subj==1	

bysort collection_code: tab semester

bysort  mastid year: gen mkid_coll=_n 
bysort  mastid year: gen rkid_coll=_n
	
bysort math_subj mastid year subject_id: gen my_course=_n if math_subj==1
egen   nmy_course=total(my_course) if math_subj==1 & my_course==1, by(mastid year)
egen   my_num_course=max(nmy_course) if math_subj==1, by(mastid year)

bysort read_subj mastid year subject_id: gen ry_course=_n if read_subj==1
egen   nry_course=total(ry_course) if read_subj==1 & ry_course==1, by(mastid year)
egen   ry_num_course=max(nry_course) if read_subj==1, by(mastid year)

bysort collection_code: tab math_subj, m
bysort math_subj mastid year subject_id collection_code: gen mc_course=_n if math_subj==1 & year>2008
egen   nmc_course=total(mc_course) if math_subj==1 & mc_course==1 & year>2008, by(mastid year collection_code)
egen   mc_num_course=max(nmc_course) if math_subj==1 & year>2008, by(mastid year collection_code)

gen     diff_math_coll_crsid=1 if mc_num_course!=my_num_course & year>2008 & math_subj==1
replace diff_math_coll_crsid=0 if mc_num_course==my_num_course & year>2008 & math_subj==1

egen diff_MC_crsid= max(diff_math_coll_crsid), by(mastid year)

tab diff_MC_crsid if mkid_coll==1 & year>2008 

bysort collection_code: tab read_subj, m
bysort read_subj mastid year subject_id collection_code: gen rc_course=_n if read_subj==1 & year>2008
egen   nrc_course=total(rc_course) if read_subj==1 & rc_course==1 & year>2008, by(mastid year collection_code)
egen   rc_num_course=max(nrc_course) if read_subj==1 & year>2008, by(mastid year collection_code)

gen     diff_read_coll_crsid=1 if rc_num_course!=ry_num_course & year>2008 & read_subj==1
replace diff_read_coll_crsid=0 if rc_num_course==ry_num_course & year>2008 & read_subj==1
egen    diff_RC_crsid= max(diff_read_coll_crsid), by(mastid year)

tab diff_RC_crsid if rkid_coll==1 & year>2008

bysort math_subj mastid year teachid: gen mt_course=_n if math_subj==1
egen nmt_course=total(mt_course) if math_subj==1 & mt_course==1, by(mastid year)
egen mt_num_course=max(nmt_course) if math_subj==1, by(mastid year)

bysort read_subj mastid year teachid: gen rt_course=_n if read_subj==1
egen nrt_course=total(rt_course) if read_subj==1 & rt_course==1 , by(mastid year)
egen rt_num_course=max(nrt_course) if read_subj==1, by(mastid year)

gen     mteach_switch_coll=1 if mt_num_course>=my_num_course  & math_subj==1
replace mteach_switch_coll=0 if mt_num_course< my_num_course  & math_subj==1

egen mteach_cc=max(mteach_switch_coll), by(mastid year)

gen     rteach_switch_coll=1 if rt_num_course>=ry_num_course  & read_subj==1
replace rteach_switch_coll=0 if rt_num_course< ry_num_course  & read_subj==1	

egen rteach_cc=max(rteach_switch_coll), by(mastid year)	
bysort diff_MC_crsid mastid year: gen mkid_teach=_n
bysort diff_RC_crsid mastid year: gen rkid_teach=_n

tab mteach_cc if mkid_teach==1 & year>2008 & diff_MC_crsid==1
tab rteach_cc if rkid_teach==1 & year>2008 & diff_RC_crsid==1
	 drop my_course nmy_course my_num_course ry_course nry_course ry_num_course ///
      mkid_coll rkid_coll mt_course nmt_course mt_num_course rt_course ///
      nrt_course rt_num_course mkid_teach rkid_teach diff_read_coll_crsid ///
      diff_math_coll_crsid rteach_switch_coll mteach_switch_coll

tab semester if math_subj==1
tab semester if read_subj==1

bysort grade: tab semester if math_subj==1
bysort grade: tab semester if read_subj==1 

bysort math_subj mastid year subject_id: gen my_course=_n if math_subj==1
egen   nmy_course=total(my_course) if math_subj==1 & my_course==1, by(mastid year)
egen   my_num_course=max(nmy_course) if math_subj==1, by(mastid year)

bysort read_subj mastid year subject_id: gen ry_course=_n if read_subj==1
egen   nry_course=total(ry_course) if read_subj==1 & ry_course==1, by(mastid year)
egen   ry_num_course=max(nry_course) if read_subj==1, by(mastid year)

bysort math_subj mastid year subject_id semester: gen ms_course=_n if math_subj==1 
egen   nms_course=total(ms_course)   if math_subj==1 & ms_course==1, by(mastid year semester) 
egen   ms_num_course=max(nms_course) if math_subj==1, by(mastid year semester)	

bysort read_subj mastid year subject_id semester: gen rs_course=_n if read_subj==1 
egen   nrs_course=total(rs_course)   if read_subj==1 & rs_course==1, by(mastid year semester) 
egen   rs_num_course=max(nrs_course) if read_subj==1, by(mastid year semester)

	
gen     diff_math_sem_crsid=1 if my_num_course!=ms_num_course & math_subj==1  
replace diff_math_sem_crsid=0 if my_num_course==ms_num_course & math_subj==1
egen    diff_MS_crsid=max(diff_math_sem_crsid), by(mastid year)

gen     diff_read_sem_crsid=1 if ry_num_course!=rs_num_course  & read_subj==1
replace diff_read_sem_crsid=0 if ry_num_course==rs_num_course  & read_subj==1

egen    diff_RS_crsid=max(diff_read_sem_crsid), by(mastid year)

bysort mastid year: gen kid_yr=_n
*Math
tab diff_MS_crsid if kid_yr==1
*Read
tab diff_RS_crsid if kid_yr==1

bysort math_subj mastid year teachid: gen mt_course=_n if math_subj==1
egen nmt_course=total(mt_course)   if math_subj==1 & mt_course==1, by(mastid year)
egen mt_num_course=max(nmt_course) if math_subj==1, by(mastid year)

bysort read_subj mastid year teachid: gen rt_course=_n if read_subj==1
egen nrt_course=total(rt_course)   if read_subj==1 & rt_course==1 , by(mastid year)
egen rt_num_course=max(nrt_course) if read_subj==1, by(mastid year)

gen     mteach_switch_sem=1 if mt_num_course>=my_num_course  & math_subj==1
replace mteach_switch_sem=0 if mt_num_course< my_num_course  & math_subj==1

egen mteach_sm=max(mteach_switch_sem), by(mastid year)

gen     rteach_switch_sem=1 if rt_num_course>=ry_num_course  & read_subj==1
replace rteach_switch_sem=0 if rt_num_course< ry_num_course  & read_subj==1	

egen rteach_sm=max(rteach_switch_sem), by(mastid year)	

bysort diff_MS_crsid mastid year: gen ms_kid_yr=_n
bysort diff_RS_crsid mastid year: gen rs_kid_yr=_n

* MATH
tab mteach_sm if diff_MS_crsid==1 & ms_kid_yr==1
*Read
tab rteach_sm if diff_RS_crsid==1 & rs_kid_yr==1

replace subject="ap calculus" if subject_id=="2076"
replace subject="other math topics" if subject_id=="2006" | subject_id=="2010" | subject_id=="2016" | subject_id=="2032"
replace subject="language arts" if subject_id=="010Z"
replace subject_id="1010" 	if subject_id=="010Z"


cd $data
cd coursemembership
save 5crs_memb2007_2014.dta, replace

*fall/ spring semester
gen fall          =(collection_code=="FDF" | collection_code=="")
egen xfall        =max(fall), by(mastid year)
replace fall= 1 if xfall==0 & fall==0 & collection_code=="FDS"
egen min_sem      =min(semester) if fall==1, by(mastid year subject_id)
gen fall_first_sem=(semester==min_sem & fall==1)
 drop rr_course mmcrs_num rrcrs_num has_mult_mm has_mult_rr 
bysort fall_first_sem math_subj mastid year subject_id: gen mm_course=_n if math_subj==1 & fall_first_sem==1
bysort fall_first_sem read_subj mastid year subject_id: gen rr_course=_n if read_subj==1 & fall_first_sem==1

egen mmcou_num  =total(mm_course) if mm_course==1 & math_subj==1 & fall_first_sem, by(mastid year)
egen mmcrs_num  =max(mm_course)   if math_subj==1 & fall_first_sem==1, by(mastid year)
gen  has_mult_mm=(mmcrs_num>1)    if math_subj==1 & fall_first_sem==1 & !missing(mmcrs_num)

egen rrcou_num  =total(rr_course) if rr_course==1 & read_subj==1 & fall_first_sem, by(mastid year)
egen rrcrs_num  =max(rrcou_num)   if read_subj==1 & fall_first_sem==1, by(mastid year)
gen  has_mult_rr=(rrcrs_num>1)    if read_subj==1 & fall_first_sem==1 & !missing(rrcrs_num)

drop r_course m_course
bysort fall_first_sem math_subj mastid year: gen m_course=_n if math_subj==1 & fall_first_sem==1
bysort fall_first_sem read_subj mastid year: gen r_course=_n if read_subj==1 & fall_first_sem==1

tab has_mult_mm if m_course==1
tab has_mult_rr if r_course==1

bysort fall_first_sem math_subj mastid year teachid: gen mst_course=_n if math_subj==1 & fall_first_sem==1
egen nmst_course=total(mst_course)   if math_subj==1 & mst_course==1 & fall_first_sem==1, by(mastid year)
egen mst_num_course=max(nmst_course) if math_subj==1 & fall_first_sem==1, by(mastid year)

bysort fall_first_sem read_subj mastid year teachid: gen rst_course=_n if read_subj==1 & fall_first_sem==1
egen nrst_course=total(rst_course)   if read_subj==1 & rst_course==1 & fall_first_sem==1, by(mastid year)
egen rst_num_course=max(nrst_course) if read_subj==1 & fall_first_sem==1, by(mastid year)

gen     mteach_switchcrs=1 if mst_num_course>=mmcrs_num  & math_subj==1 & fall_first_sem==1
replace mteach_switchcrs=0 if mst_num_course< mmcrs_num  & math_subj==1 & fall_first_sem==1

egen mteach_crs=max(mteach_switchcrs) if math_subj==1 & fall_first_sem==1, by(mastid year)

gen     rteach_switchcrs=1 if rst_num_course>=rrcrs_num  & read_subj==1 & fall_first_sem==1
replace rteach_switchcrs=0 if rst_num_course< rrcrs_num  & read_subj==1 & fall_first_sem==1	

egen rteach_crs=max(rteach_switchcrs) if read_subj==1 & fall_first_sem==1, by(mastid year)	

bysort has_mult_mm fall_first_sem math_subj mastid year: gen mkid_moret=_n if has_mult_mm==1 & fall_first_sem==1
bysort has_mult_rr fall_first_sem read_subj mastid year: gen rkid_moret=_n if has_mult_rr==1 & fall_first_sem==1

tab mteach_crs if mkid_more==1
tab rteach_crs if rkid_more==1

gen middle_schl=(grade>5)
gen elem_schl  =(grade<=5)

gen 	math_course_switch_drop= 1 if subject=="math (k-8)" & math_subj==1 & fall_first_sem==1 & mteach_switchcrs==1 & has_mult_mm==1	
replace math_course_switch_drop= 0 if subject!="math (k-8)" & math_subj==1 & fall_first_sem==1 & mteach_switchcrs==1 & has_mult_mm==1

egen    ma_crs_sw_dp=max(math_course_switch_drop) if math_subj==1 & fall_first_sem==1 & mteach_switchcrs==1 & has_mult_mm==1	

replace math_course_switch_drop=1 if math_course_switch_drop==0 & ma_crs_sw_dp==0 & subject=="self-contained" & math_subj==1 & fall_first_sem==1 & mteach_switchcrs==1 & has_mult_mm==1

gen 	read_course_switch_drop=1 if subject=="language arts" & read_subj==1 & fall_first_sem==1 & rteach_switchcrs==1 & has_mult_rr==1		
replace read_course_switch_drop=0 if subject!="language arts" & read_subj==1 & fall_first_sem==1 & rteach_switchcrs==1 & has_mult_rr==1

egen rd_crs_sw_dp=max(read_course_switch_drop) if read_subj==1 & fall_first_sem==1 & rteach_switchcrs==1 & has_mult_rr==1	

replace read_course_switch_drop=1  if read_course_switch_drop==0 & rd_crs_sw_dp==0 & subject=="reading" & read_subj==1 & fall_first_sem==1 & rteach_switchcrs==1 & has_mult_rr==1


drop if math_course_switch_drop==0
drop if read_course_switch_drop==0

   
bysort fall_first_sem math_subj mastid year teachid: gen mteach_yr=_n if fall_first_sem==1 & math_subj==1
bysort fall_first_sem read_subj mastid year teachid: gen rteach_yr=_n if fall_first_sem==1 & read_subj==1
egen num_math_teach_yr=total(mteach_yr) if fall_first_sem==1 & math_subj==1 & mteach_yr==1, by(mastid year)
egen xnum_math_teach_yr= max(num_math_teach_yr) if fall_first==1 & math_subj==1, by(mastid year)
egen num_read_teach_yr=total(rteach_yr) if fall_first_sem==1 & read_subj==1 & rteach_yr==1, by(mastid year)
egen xnum_read_teach_yr= max(num_read_teach_yr) if fall_first_sem==1 & read_subj==1, by(mastid year)

bysort fall_first_sem math_subj mastid year coursetitle section: gen mclass_yr=_n if fall_first_sem==1 & math_subj==1
egen   num_math_crs_yr=total(mclass_yr) if fall_first_sem==1 & math_subj==1 & mclass_yr==1, by(mastid year)
egen  xnum_math_crs_yr= max(num_math_crs_yr) if fall_first_sem==1 & math_subj==1, by(mastid year)

bysort fall_first_sem read_subj mastid year coursetitle section: gen rclass_yr=_n if fall_first_sem==1 & read_subj==1
egen   num_read_crs_yr=total(rclass_yr) if fall_first_sem==1 & read_subj==1 & rclass_yr==1, by(mastid year)
egen  xnum_read_crs_yr=max(num_read_crs) if fall_first_sem==1 & read_subj==1, by(mastid year)

bysort fall_first_sem math_subj mastid year: gen kid_m_fyr=_n if math_subj==1 & fall_first_sem==1
bysort fall_first_sem read_subj mastid year: gen kid_r_fyr=_n if read_subj==1 & fall_first_sem==1

tab1 xnum_math_teach_yr xnum_math_crs_yr if kid_m_fyr==1
tab1 xnum_read_teach_yr xnum_read_crs_yr if kid_r_fyr==1

bysort fall_first_sem math_subj has_mult_mm mteach_switchcrs mastid year: gen kid_m_mm_swt=_n  if fall_first_sem==1 & math_subj==1 & mteach_switchcrs==1 & has_mult_mm==1
bysort fall_first_sem read_subj has_mult_rr rteach_switchcrs mastid year: gen kid_r_rr_swt=_n  if fall_first_sem==1 & read_subj==1 & rteach_switchcrs==1 & has_mult_rr==1 

tab   xnum_math_teach_yr if kid_m_mm_swt==1
tab   xnum_read_teach_yr if kid_r_rr_swt==1

gen    mult_read_class=(xnum_read_crs_yr>1) if fall_first_sem==1 & read_subj==1 & !missing(xnum_read_crs_yr)
bysort fall_first_sem read_subj mult_read_class mastid year: gen kid_mr_nt=_n if fall_first_sem==1 & read_subj==1 & mult_read_class==1
tab xnum_read_teach_yr if kid_mr_nt==1

cd $data
cd coursemembership
save 6crs_memb2007_2012.dta, replace

gen    mult_read_teacher=(xnum_read_teach_yr>1) if fall_first_sem==1 & read_subj==1 & !missing(xnum_read_teach_yr)
gen    mult_math_class  =(xnum_math_crs_yr>1)   if fall_first_sem==1 & math_subj==1 & !missing(xnum_math_crs_yr)
gen    mult_math_teacher=(xnum_math_teach_yr>1) if fall_first_sem==1 & math_subj==1 & !missing(xnum_math_teach_yr)

drop if mult_read_teacher==1 & mult_read_class==1 
drop if mult_math_teacher==1 & mult_math_class==1
	
* students with multiple teachers 
drop if mult_read_teacher==1 & mult_read_class==0 
drop if mult_math_teacher==1 & mult_math_class==0

keep if fall_first_sem==1

sort mastid year grade lea_r schlcode_fl coursetitle section
duplicates drop mastid year grade lea_r schlcode_fl coursetitle section, force 

	cd $data
save 01_math_read_classes.dta, replace

	
log close


