clear all
version 13
set more off
do "/home/home2/qureshi_rs1/teacher_sorting/directory_do"

cd "$data"
****************************************
INPUT FILES:  VAM_data.dta

OUTPUT FILES: va_data.dta /*student level data*/
tchr_va.dta /*teacher level data */
sgy_va.dta /*school-grade-year level data*/
******************************
use VAM_data.dta, clear

*missing scores
g read_mis = read==.
bys mastid year read_subj: egen read1 = min(read_mis)
bys mastid year read_subj: egen read2 = max(read_mis)
count if read1!=read2
drop if read==. & read1!=read2 & read_subj==1

g math_mis = math==.
bys mastid year read_subj: egen math1 = min(math_mis)
bys mastid year read_subj: egen math2 = max(math_mis)
count if math1!=math2
drop if math==. & math1!=math2 & math_subj==1

*duplicates
sort mastid year teachid read_subj coursetitle
qui by mastid year teachid read_subj coursetitle:  gen dup1 = cond(_N==1,0,_n)
drop if dup1>0
drop dup1
sort mastid year read_subj teachid
sort mastid year read_subj teachid coursetitle
qui by mastid year read_subj teachid:  gen dup1 = cond(_N==1,0,_n)
bys mastid year read_subj: egen teachid1 = min(teachid)
bys mastid year read_subj: egen teachid2 = max(teachid)
count if teachid1!=teachid2 & read_subj==1 
g teachid_mis = teachid==.
tab teachid_mis if read_subj==1

encode coursetitle, gen(coursetitlen)
bys mastid year read_subj: egen coursetitle1 = min(coursetitlen) 
bys mastid year read_subj: egen coursetitle2 = max(coursetitlen)
count if dup1>0 
count if coursetitle1!=coursetitle2 & dup1>0 
/*All of duplicates are due to different coursetitles*/
tab dup1 if coursetitlen==coursetitle1 
keep if coursetitlen==coursetitle1 

tab dup1
sort mastid year read_subj teachid
qui by mastid year read_subj teachid:  gen dup1b = cond(_N==1,0,_n)
tab dup1b
*No more duplicates
drop dup1 dup1b
sort mastid year read_subj
qui by mastid year read_subj :  gen dup = cond(_N==1,0,_n)
tab dup
drop dup

*Sample restrictions - drop student observations if 1) their teacher is teaching <10 | >50 students  
*or 2) teacher is teaching more than 25% disabled students 

*Reading courses
*Create nstudt taught by each teacher

bys schgryr teachid read_subj: gen nrstudt = _N 
replace nrstudt = . if read_subj==0
g droprclass1 = nrstudt<10 | nrstudt>50 if read_subj==1

egen pctdis_rclass =mean(disabled), by(schgryr teachid read_subj) 
replace pctdis_rclass=. if read_subj==0
g droprclass2 = pctdis_rclass>0.25 | pctdis_rclass==. if read_subj==1

bys schgryr: egen sgyhasdroprclass1 = max(droprclass1)
bys schgryr: egen sgyhasdroprclass2 = max(droprclass2)
g sgyhasanydroprclass = sgyhasdroprclass1==1 | sgyhasdroprclass2==1

drop if droprclass1==1 | droprclass2==1
drop droprclass1 droprclass2

*Math course
*Create nstudt taught by each teacher
bys schgryr teachid math_subj: gen nmstudt = _N 
replace nmstudt = . if math_subj==0

g dropmclass1 = nmstudt<10 | nmstudt>50 if math_subj==1

egen pctdis_mclass =mean(disabled), by(schgryr teachid math_subj) 
replace pctdis_mclass=. if math_subj==0
g dropmclass2 = pctdis_mclass>0.25 | pctdis_mclass==. if math_subj==1

bys schgryr: egen sgyhasdropmclass1 = max(dropmclass1)
bys schgryr: egen sgyhasdropmclass2 = max(dropmclass2)
g sgyhasanydropmclass = sgyhasdropmclass1==1 | sgyhasdropmclass2==1

drop if dropmclass1==1 | dropmclass2==1
drop dropmclass1 dropmclass2


******************************
*Drop the year in which child is grade repeater 
drop if grade_repeat ==1

generate agegrp=recode(Age,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20)
char agegrp[omit] 5
xi i.agegrp , prefix(AGE)

xi i.grade, prefix(GRD)
xi i.year,  prefix(YR)

*save
cd "$data"
save VAMdata.dta, replace

label define middle 0 elementary 1 middle
label define math 0 "not math" 1 math
label define read 0 "not reading" 1 reading
label values middle_schl middle
label values math_subj math
label values read_subj read

replace math_subj=. if math_subj==0
replace read_subj=. if read_subj==0

global basecontrols eds Black White Hispanic Female AGE* grade_repeat premath lep_flag ///
                    disabled preread premath2 premath3 preread2 preread3 PREM* PRER*  ///
		    SY_Black SY_White SY_Hispanic SY_Female SY_disabled SY_Age ///
		    SY_eds SY_lep_flag SY_grade_repeat SGY* SGMA* SGRD* CL_Black ///
		    CL_White CL_Hispanic CL_Female CL_disabled CL_Age CL_eds ///
		    CL_lep_flag CL_grade_repeat CL_premath CL_preread CL_premath2 ///
		    CL_premath3 CL_preread2 CL_preread3 CLMA* CLRD* GRD* YR* class_size_t

*Create VA with tchr f.e.
*abbreviations
*	tfe = teacher fixed effect
*	m = middle school
*	e = elementary school

xi: areg math $basecontrols if math_subj==1 & middle_schl==0 & grade!=3, absorb(teachid)
predict math_tfe, d
xi: areg read $basecontrols if read_subj==1 & middle_schl==0 & grade!=3, absorb(teachid)
predict read_tfe, d
reg math math_tfe if math_subj==1 & middle_schl==0 & grade!=3
reg math math_tfe $basecontrols if math_subj==1 & middle_schl==0 & grade!=3
reg read read_tfe if read_subj==1 & middle_schl==0 & grade!=3
reg read read_tfe $basecontrols if read_subj==1 & middle_schl==0 & grade!=3

bys teachid: egen math_va = max(math_tfe)
bys teachid: egen read_va = max(read_tfe)
cd "$data"
save va_data.dta, replace

*create teacher-level dataset of VA*
*************************************************************
collapse sfe math_va read_va, by(teachid)

egen avgva = rowmean(math_va read_va)
egen sd_avgva = sd(avgva)
egen m_avgva = mean(avgva)
g va = (avgva - m_avgva)/sd_avgva

egen sd_mathva = sd(math_va)
egen m_mathva = mean(math_va)
g mathva_std = (math_va - m_mathva)/sd_mathva

egen sd_readva = sd(read_va)
egen m_readva = mean(read_va)
g readva_std = (read_va - m_readva)/sd_readva

label var va "Standardized Teacher VA"
label var mathva_std "Standardized Teacher Math VA"
label var readva_std "Standardized Teacher Read VA"

drop sd_avgva m_avgva sd_mathva m_mathva sd_readva m_readva

cd "$data"
sa tchr_va.dta, replace

************************************
*Create SGY Level mean and SD of VA*
***********************************

*Create VA SD
merge 1:m teachid using va_data.dta

sort lea_r schlcode_fl year grade teachid mastid 

egen schgryrtchr = group(schgryr teachid)

collapse va schlcode_fl lea_r year grade teachid schgryr, by(schgryrtchr) 
sort schgryr
by schgryr: egen vasd_sgy = sd(va) 
label var vasd_sgy "SGY SD of standardized teacher VA"

by schgryr, sort: egen ntchrs = count(teachid)

replace vasd_sgy = 0 if ntchrs==1 
egen medianvasd = median(vasd_sgy)
egen meanvasd = mean(vasd_sgy)

g hivasd = vasd_sgy>medianvasd if vasd_sgy!=.
g hivasd2 = vasd_sgy>meanvasd if vasd_sgy!=.

collapse vasd_sgy hivasd hivasd2  schlcode_fl lea_r year grade, by(schgryr) 
sa sgy_vasd.dta, replace

*Create mean VA
use tchr_va.dta, clear
merge 1:m teachid using va_data.dta

sort lea_r schlcode_fl year grade teachid mastid 
collapse va avgva schlcode_fl lea_r year grade, by(schgryr) 
*VA is a student-weighted average of the standardized value added in the school-grade-year
*avgva is a student weighted average of the non-standardized value added in the school-grade-year

ren va va_sgy 
ren avgva va2_sgy

label var va_sgy "SGY student-weighted mean of read-math average teacher VA that was standardized to have mean 0 SD 1 at teacher level"
label var va2_sgy "SGY student-weighted mean of read-math average teacher VA"

sa sgy_va.dta, replace
********************************************************************************************************************************************
